@@ -113,7 +113,7 @@ class CohortRepoClass:
                 raise InvalidParameterException("dataset_id")
             ssl._create_default_https_context = ssl._create_unverified_context
             obj = OmixAtlas()
-            download_dict = obj.download_data(repo_info, dataset_id)
+            download_dict = obj.download_data(repo_info, dataset_id, internal_call=True)
             url = (
                 download_dict.get("data", {}).get("attributes", {}).get("download_url")
             )
