@@ -476,7 +476,10 @@ def make_private_link(
     """
     Function to construct and return a private link for a file in workspace.
     """
-    file_element = {"path": f"/projects/{workspace_id}/files/{workspace_path}"}
+    # encoding the workspace_path for any special character that might pe present in the file_name,
+    # example: 18891/report@name.html
+    parsed_path = urllib.parse.quote(workspace_path)
+    file_element = {"path": f"/projects/{workspace_id}/files/{parsed_path}"}
     if report_id:
         return f"{constant_url}/restricted/file?id={workspace_id}&{urllib.parse.urlencode(file_element)}&report_id={report_id}"
     else:
@@ -495,9 +498,11 @@ def change_file_access(
     Function to change the file access as per the access_key and returns the final access url
     """
     final_url = ""
+    # encoding workspace path in case of special characters
+    parsed_workspace_path = urllib.parse.quote(workspace_path)
     if access_key == "private":
         params = {"action": "share", "access_type": "private"}
-        url = f"{self.base_url}/projects/{workspace_id}/files/{workspace_path}"
+        url = f"{self.base_url}/projects/{workspace_id}/files/{parsed_workspace_path}"
         # API call to change the file access to private
         response = self.session.get(url, params=params)
         error_handler(response)
@@ -506,7 +511,7 @@ def change_file_access(
         )
     else:
         params = {"action": "share", "access_type": "global"}
-        url = f"{self.base_url}/projects/{workspace_id}/files/{workspace_path}"
+        url = f"{self.base_url}/projects/{workspace_id}/files/{parsed_workspace_path}"
         # API call to change the file access to public
         response = self.session.get(url, params=params)
         error_handler(response)
@@ -993,3 +998,18 @@ def get_folder_list_from_list_of_filepaths(filenames_fullpath_list: list) -> lis
         folder_name = os.path.normpath(os.path.dirname(full_file_path))
         list_folder_names.append(folder_name)
     return list(set(list_folder_names))
+
+
+def make_query_for_discover_api(page_size, dataset_id):
+    query = {
+        "query": {
+            "term": {
+                # Count entries for the following key-value pairs
+                "src_dataset_id.keyword": dataset_id
+            }
+        },
+        # Fetch X many rows at a time (you will still get the full output, which may be greater than 10K)
+        # Setting this value to be greater than 10k will result in an error
+        "size": page_size,
+    }
+    return query
