@@ -183,12 +183,15 @@ class jobs:
             else:
                 sortedJobsTemp = postDatas.json()
                 sortedJobs.extend(sortedJobsTemp.get("data"))
+                # TODO: can remove this looping with dev testing
                 for i in range(len(sortedJobsTemp.get("data"))):
                     if sortedJobsTemp.get("links", "") and sortedJobsTemp.get(
                         "links", ""
                     ).get("next", ""):
-                        jobUrl = f"{self.base_url}{sortedJobsTemp.json().get('links').get('next')}"
-                        postDatas = self._get_data_for_job_id(self, jobUrl)
+                        jobUrl = (
+                            f"{self.base_url}{sortedJobsTemp.get('links').get('next')}"
+                        )
+                        postDatas = self._get_data_for_job_id(jobUrl)
                         if postDatas.status_code != const.OK:
                             self._handle_response_errors(postDatas)
                         sortedJobsTemp = postDatas.json()
