@@ -1,8 +1,10 @@
 import os
 import copy
+from functools import lru_cache
 import requests
 import pathlib
 import json
+from tabulate import tabulate
 import warnings
 from pathlib import Path
 from polly.errors import (
@@ -14,7 +16,7 @@ from polly.errors import (
     InvalidSyntaxForRequestException,
 )
 
-# import pandas as pd
+import pandas as pd
 import polly.constants as const
 from cryptography.fernet import Fernet
 from polly.errors import error_handler, ValidationError
@@ -1077,6 +1079,361 @@ def compare_repo_id_and_id(repo_id: str, id: str):
         )
 
 
+def extract_error_message(error_msg) -> str:
+    """
+    Extract error message from the error
+    """
+    error_msg = json.loads(error_msg)
+    error = error_msg.get("error")
+    if error is None:
+        error = error_msg.get("errors")[0]
+    if "detail" in error:
+        detail = error.get("detail")
+
+    return detail
+
+
+def dataset_id_type_check_in_delete_datasets(dataset_ids: list):
+    """Dataset Id type check in delete datasets
+
+    Args:
+        dataset_id (list): dataset ids list
+    """
+    if not (dataset_ids and isinstance(dataset_ids, list)):
+        raise paramException(
+            title="Param Error",
+            detail="dataset_ids should be list of strings",
+        )
+
+
+def dataset_file_path_dict_type_check_in_delete_datasets(dataset_file_path_dict: dict):
+    """dataset_file_path_dict type check in delete datasets
+
+    Args:
+        dataset_file_path_dict (dict): dict of dataset_file_path_dict
+    """
+    if not isinstance(dataset_file_path_dict, dict):
+        raise paramException(
+            title="Param Error",
+            detail=(
+                "dataset_file_path_dict should be dict -> {<dataset_id>:<list_of_paths>}",
+            ),
+        )
+
+    for key, val in dataset_file_path_dict.items():
+        if not isinstance(val, list):
+            raise paramException(
+                title="File paths datatype is incorrect",
+                detail=(
+                    "File paths should be in the format of list of strings in the "
+                    + "dataset_file_path_dict. Correct format -> {<dataset_id>:<list_of_paths>}"
+                ),
+            )
+        if not isinstance(key, str):
+            raise paramException(
+                title="dataset_id datatype is incorrect",
+                detail=(
+                    "dataset_id should be in the format of string in the "
+                    + "dataset_file_path_dict. Correct format -> {<dataset_id>:<list_of_paths>}"
+                ),
+            )
+
+
+def parameter_check_for_delete_dataset(
+    repo_id: int, dataset_ids: list, dataset_file_path_dict: dict
+):
+    """
+    Sanity check for all the parameters of delete datasets
+    """
+    try:
+        parameter_check_for_repo_id(repo_id)
+        dataset_id_type_check_in_delete_datasets(dataset_ids)
+        dataset_file_path_dict_type_check_in_delete_datasets(dataset_file_path_dict)
+    except Exception as err:
+        raise err
+
+
+def dataset_file_path_is_subset_dataset_id(
+    dataset_ids: list, dataset_file_path_dict: dict
+):
+    """Check if all the keys of dataset_file_path_dict which represents dataset id
+    are present in dataset_ids list or not
+    Ideally all the dataset id present as key in dataset_file_path_dict should be mandatorily
+    present in the dataset_ids list
+    i.e. All the keys of dataset_file_path_dict should be a subset of dataset_ids list
+    The function is to check the subset validity
+
+    Args:
+        dataset_ids (list): List of dataset ids
+        dataset_file_path_dict (dict): Dictionary containing dataset ids and file paths
+        corresponding to it
+
+    Raises:
+        paramError: If Params are not passed in the desired format or value not valid.
+
+    """
+    dataset_file_path_dict_keys = dataset_file_path_dict.keys()
+
+    # converting both the lists and checking for the error case
+    # Error Case -> dataset_file_path_dict_keys list not a subset of dataset_ids list
+    # in that case raise warnings for those dataset_ids
+    # which are a part of dataset_file_path_dict but not dataset_ids
+    # For Example
+    # a = [1, 3, 5]
+    # b = [1, 3, 5, 8]
+    # set(a) <= set(b)
+    # ANS -> TRUE
+    if not set(dataset_file_path_dict_keys) <= set(dataset_ids):
+        # find the difference of elements present in dataset_file_path_dict_keys list
+        # that are not present in dataset_ids list
+        # Example ->
+        # list_1 = ['a', 'b', 'c']
+        # list_2 = ['a', 'd', 'e']
+        # result_1 = list(set(list_2).difference(list_1))
+        # print(result_1)  # 👉️ ['e', 'd']
+        invalid_dataset_ids = list(
+            set(dataset_file_path_dict_keys).difference(dataset_ids)
+        )
+        warnings.formatwarning = lambda msg, *args, **kwargs: f"WARNING: {msg}\n"
+        warnings.warn(
+            f"Unable to delete these dataset_ids {invalid_dataset_ids} because "
+            + "these are not present in dataset_ids list. "
+            + "For any questions, please reach out to polly.support@elucidata.io. "
+        )
+        # break line added -> for better UX
+        print("\n")
+
+
+# cached for the cases when this function is called internally when same
+# result is needed multiple times
+@lru_cache(maxsize=None)
+def list_files(
+    self: dict, repo_id: str, metadata="true", data="true", version="current"
+) -> list:
+    """helper function to integrate list files API response
+
+    Args:
+        self (dict): dictionary storing session vara
+        repo_id (str): repo id of the omixatlas
+    Returns:
+        list_files_resp -> list of objects with requests type
+    """
+    # page_size -> for paginating the API
+    files_api_endpoint = f"{self.discover_url}/repositories/{repo_id}/files"
+    # initialising an empty value of next link
+    next_link = ""
+    responses_list = []
+    # once the pages will end -> next_link will be
+    # set to None by the API
+    while next_link is not None:
+        if next_link:
+            next_endpoint = f"{self.discover_url}{next_link}"
+            response = self.session.get(next_endpoint)
+        else:
+            # getting the response for the first 1000 pages initially
+            query_params = {
+                "page[size]": 1000,
+                "page[after]": 0,
+                "include_metadata": f"{metadata}",
+                "data": f"{data}",
+                "version": f"{version}",
+            }
+            response = self.session.get(files_api_endpoint, params=query_params)
+        response.raise_for_status()
+        response_json = response.json()
+        # list of request objects
+        # request object having both status and data of the response
+        responses_list.append(response)
+        # seeing after 1000 pages whose response is already fetched
+        # if there are more pages
+        next_link = response_json.get("links").get("next")
+
+    return responses_list
+
+
+def normalize_file_paths(dataset_file_path_dict: dict):
+    """Normalise all the file paths in the dataset_file_path_dict
+
+    Args:
+        dataset_file_path_dict (dict): key is dataset id and value is the file_path
+    """
+    # iterating over the dictionary containing dataset_id and list of file paths
+    # format: {<dataset_id>:[<file_path_1>, ........., <file_path_n>]}
+    for dataset_id, file_path_list in dataset_file_path_dict.items():
+        # iterating over the list of file paths and
+        # normalising each file path and storing in
+        # normalised_file_path_list which will be mapped to
+        # dataset_id
+        normalised_file_path_list = []
+        for file_path in file_path_list:
+            normalised_file_path = os.path.normpath(file_path)
+            normalised_file_path_list.append(normalised_file_path)
+        dataset_file_path_dict[dataset_id] = normalised_file_path_list
+    return dataset_file_path_dict
+
+
+# TODO -> @shilpa to make a ticket for this to make this generic enough
+def check_res_dict_has_file_deleted_entries(result_dict: dict) -> bool:
+    """Check if result_dict has entries for deleted files
+    If res_dict has entries of deleted files, then only commit API will be
+    called else commit API will not be called
+    This will ensure that commit API is only called when actually there is an
+    entry in the DF where files are deleted
+
+    Args:
+        result_dict (dict): DF containing messages from the API corresponding to
+        deletion request
+
+    Returns:
+        bool: Flag to show if any dataset_id from the result_dict have deleted message
+    """
+    # valid_deletion_entry is initalized to false -> if no deletion entry is valid
+    # then False flag will be returned -> commit API will not be hit
+    valid_deletion_entry = False
+    # Example result_dict
+    # {'GSE140509_GPL16791':
+    # {'Message': 'Request Accepted. Dataset will be deleted in the next version of OmixAtlas',
+    # 'Folder Path': 'transcriptomics_213/GSE140509_GPL16791.gct'}}
+
+    # if message string has `Request Accepted` substring then deletion for that dataset_id
+    # has been accepted
+    # if in any of the other entries -> the deletion request is accepted -> means
+    # at least one dataset_id has valid deletion entry -> commit will be hit then
+    # for deletion request -> break the loop there
+
+    # TODO ->
+    # i. Make this more generic enough
+    # ii. ( any(any('Request Accepted' in deletion_res["Message"])
+    # for deletion_res in result_dict.values()) )
+
+    for dataset_id, deletion_res_list in result_dict.items():
+        for deletion_res in deletion_res_list:
+            message = deletion_res["Message"]
+            if "Request Accepted" in message:
+                valid_deletion_entry = True
+                break
+
+    return valid_deletion_entry
+
+
+def user_file_path_incorrect(user_file_path: str, datasetid_key: str):
+    """If user_file_path not equal to file_path passed by the user
+
+    Args:
+        user_file_path (str): file_path passed by the user in dataset_file_path_dict
+        datasetid_key (str): dataset_id for which file_path passed
+    """
+    # passed file path by the user is does not contain the file
+    # raise a warning and store an error message corresponding to
+    # dataset_id and return
+    warnings.formatwarning = lambda msg, *args, **kwargs: f"WARNING: {msg}\n"
+    warnings.warn(
+        "Unable to delete file from the file_path "
+        + f"{user_file_path} because the file corresponding to the "
+        + f"dataset id {datasetid_key} is not present in this file_path. "
+        + "This dataset_id file is present only in 1 path so passing path "
+        + "using optional parameter not required here. "
+        + "For any questions, please reach out to polly.support@elucidata.io. "
+    )
+    # break line added -> for better UX
+    print("\n")
+    res = {
+        "Message": "Dataset not deleted because file_path for the dataset_id is incorrect",
+        "Folder Path": f"{user_file_path}",
+    }
+    return res
+
+
+def convert_delete_datasets_res_dict_to_df(result_dict: dict):
+    """Convert result dict of delete datasets to df
+    Key -> dataset_id
+    Value -> Message from deleted files in a list
+    DF
+    Col 1 -> DatasetId
+    Col 2 -> Message
+    Col 3 -> File Path
+
+
+    Args:
+        result_dict (dict): Dict of delete datasets result
+    """
+    # res dict format -> {"<dataset_id>":[{"<Folder_Path>":<val>, "Message":<val>}]}
+    # result dict format -> example
+    # {'GSE101942_GPL11154': [{'Message': 'Dataset not deleted because file_path for
+    #  the dataset_id is incorrect', 'Folder Path': 'transcriptomics_906s/GSE76311_GPL17586.gct'},
+    # {'Message': 'Dataset not deleted because file_path for the dataset_id is incorrect',
+    # 'Folder Path': 'transcriptomics_907s/GSE76311_GPL17586.gct'}]}
+    df_list = []
+    for key, val_list in result_dict.items():
+        for val in val_list:
+            df_1 = pd.DataFrame(
+                val,
+                index=[
+                    "0",
+                ],
+            )
+            # print(df_1)
+            df_1.insert(0, "DatasetId", key)
+            # df_1["Dataset Id"] = key
+            df_list.append(df_1)
+
+    data_delete_df = pd.concat(df_list, axis=0, ignore_index=True)
+    print(
+        tabulate(
+            data_delete_df,
+            headers="keys",
+            tablefmt="fancy_grid",
+            maxcolwidths=[None, 10, None],
+        )
+    )
+
+
+def warning_invalid_path_delete_dataset_multiple_paths(
+    invalid_path: str, datasetid_key: str
+):
+    """Function to raise warning for invalid path for dataset_ids present in
+    multiple paths
+    Args:
+        invalid_path: str
+    """
+    warnings.formatwarning = lambda msg, *args, **kwargs: f"WARNING: {msg}\n"
+    warnings.warn(
+        "Unable to delete file from these file paths "
+        + f"{invalid_path}"
+        + " because in these file paths, file corresponding to the dataset id "
+        + datasetid_key
+        + " is not present. "
+        + "Please run <omixatlas_obj>.get_all_file_paths(<repo_id>,<dataset_id>) to get all "
+        + "valid paths for this dataset_id. For any questions, please reach out to polly.support@elucidata.io. "
+    )
+    # break line added -> for better UX
+    print("\n")
+    res = {
+        "Message": "Dataset not deleted because file_path is incorrect.",
+        "Folder Path": f"{invalid_path}",
+    }
+    return res
+
+
+def get_all_file_paths_param_check(repo_id: int, dataset_id: str):
+    """Function to do sanity checks on arguments of
+    get_all_file_paths_param functions
+
+    Args:
+        repo_id (int): repo_id of the repo of the Omixatlas
+        dataset_id (str): dataset id passed by the user
+    """
+    try:
+        parameter_check_for_repo_id(repo_id)
+        if not (dataset_id and isinstance(dataset_id, str)):
+            raise paramException(
+                title="Param Error",
+                detail="dataset_ids should be a string",
+            )
+    except Exception as err:
+        raise err
+
+
 def warning_message_for_wrong_destination_folder(
     corresponding_data_file_names: list,
     required_file_name: str,
